@@ -49,7 +49,7 @@ sub new
     $self->{days} = 0 +
         ( abs( $p{weeks} * 7 ) + abs( $p{days} ) ) * $self->{sign};
 
-    $self->{minutes} = abs( ( $p{hours} * 60 ) + $p{minutes}  ) * $self->{sign};
+    $self->{minutes} = ( abs( $p{hours} * 60 ) + abs( $p{minutes} )  ) * $self->{sign};
 
     $self->{seconds} = 0 + abs( $p{seconds} ) * $self->{sign};
 
@@ -144,20 +144,24 @@ sub add_duration
 
     # we might have to normalize_nanoseconds before comparing durations
     $self->_normalize_nanoseconds if $self->{nanoseconds};
+
+    return $self;
 }
 
 sub add
 {
     my $self = shift;
-    $self->add_duration( (ref $self)->new(@_) )
+
+    return $self->add_duration( (ref $self)->new(@_) );
 }
 
-sub subtract_duration { $_[0]->add_duration( $_[1]->inverse ) }
+sub subtract_duration { return $_[0]->add_duration( $_[1]->inverse ) }
 
 sub subtract
 {
     my $self = shift;
-    $self->subtract_duration( (ref $self)->new(@_) )
+
+    return $self->subtract_duration( (ref $self)->new(@_) )
 }
 
 sub _add_overload
@@ -272,7 +276,10 @@ section of the DateTime.pm documentation for more details.
 
 =head1 METHODS
 
-DateTime::Duration has the following methods:
+Like C<DateTime> itself, C<DateTime::Duration> returns the object from
+mutator methods in order to make method chaining possible.
+
+C<DateTime::Duration> has the following methods:
 
 =over 4
 
